%{?mingw_package_header}

%global pkgname eigen3

Name:           mingw-%{pkgname}
Version:        3.3.9
Release:        %mkrel 2
Summary:        MinGW lightweight C++ template library for vector and matrix math
BuildArch:      noarch
Group:          Development/Other
# See COPYING.README
License:        MPLv2.0 and LGPLv2+ and BSD
URL:            http://eigen.tuxfamily.org/index.php?title=Main_Page
Source0:        https://gitlab.com/libeigen/eigen/-/archive/%{version}/eigen-%{version}.tar.bz2
# Since we are crosscompiling, read the comment in the file for details
Source1:        TryRunResults.cmake

# Fix cmake error due to buggy FindCUDA.cmake
# CMake Error at /usr/share/cmake/Modules/FindCUDA.cmake:675 (find_host_program):
#  Unknown CMake command "find_host_program".
# See https://gitlab.kitware.com/cmake/cmake/issues/16509
Patch0:         eigen_disable-cuda.patch

BuildRequires:  mingw32-filesystem >= 95
BuildRequires:  mingw32-gcc-c++
BuildRequires:  mingw32-gcc-gfortran
BuildRequires:  mingw32-fftw
BuildRequires:  mingw32-gmp
BuildRequires:  mingw32-mpfr

BuildRequires:  mingw64-filesystem >= 95
BuildRequires:  mingw64-gcc-c++
BuildRequires:  mingw64-gcc-gfortran
BuildRequires:  mingw64-fftw
BuildRequires:  mingw64-gmp
BuildRequires:  mingw64-mpfr

BuildRequires:  cmake

%description
%{summary}

# Mingw32
%package -n mingw32-%{pkgname}
Summary:                %{summary}

%description -n mingw32-%{pkgname}
%{summary}

# Mingw64
%package -n mingw64-%{pkgname}
Summary:                %{summary}

%description -n mingw64-%{pkgname}
%{summary}


%prep
%autosetup -p1 -n eigen-%{version}


%build
mkdir build_win32
pushd build_win32
%mingw32_cmake -C%{SOURCE1} -DEIGEN_BUILD_PKGCONFIG:BOOL=ON -DINCLUDE_INSTALL_DIR=include/%{pkgname} -DCMAKEPACKAGE_INSTALL_DIR=share/cmake/%{pkgname} -DEIGEN_TEST_CXX11=ON
popd

mkdir build_win64
pushd build_win64
%mingw64_cmake -C%{SOURCE1} -DEIGEN_BUILD_PKGCONFIG:BOOL=ON -DINCLUDE_INSTALL_DIR=include/%{pkgname} -DCMAKEPACKAGE_INSTALL_DIR=share/cmake/%{pkgname} -DEIGEN_TEST_CXX11=ON
popd
# Just as a sanity check
#mingw_make #{?_smp_mflags} buildtests


%install
%mingw_make_install


%files -n mingw32-%{pkgname}
%license COPYING.BSD COPYING.LGPL COPYING.MPL2 COPYING.README
%{mingw32_includedir}/%{pkgname}
%{mingw32_datadir}/pkgconfig/%{pkgname}.pc
%{mingw32_datadir}/cmake/%{pkgname}/

%files -n mingw64-%{pkgname}
%license COPYING.BSD COPYING.LGPL COPYING.MPL2 COPYING.README
%{mingw64_includedir}/%{pkgname}
%{mingw64_datadir}/pkgconfig/%{pkgname}.pc
%{mingw64_datadir}/cmake/%{pkgname}/



%changelog
* Thu Mar 24 2022 umeabot <umeabot> 3.3.9-2.mga9
+ Revision: 1824360
- Mageia 9 Mass Rebuild

* Mon Dec 14 2020 daviddavid <daviddavid> 3.3.9-1.mga8
+ Revision: 1657388
- new version: 3.3.9

* Wed Oct 21 2020 daviddavid <daviddavid> 3.3.8-1.mga8
+ Revision: 1637711
- new version: 3.3.8

* Fri Feb 14 2020 umeabot <umeabot> 3.3.7-3.mga8
+ Revision: 1522622
- Mageia 8 Mass Rebuild

* Sun Feb 03 2019 daviddavid <daviddavid> 3.3.7-2.mga7
+ Revision: 1362930
- rebuild for new mingw-mpfr 4.0.2

* Thu Dec 27 2018 daviddavid <daviddavid> 3.3.7-1.mga7
+ Revision: 1345230
- new version: 3.3.7

* Mon Dec 10 2018 daviddavid <daviddavid> 3.3.6-1.mga7
+ Revision: 1339945
- new version: 3.3.6

* Thu Sep 20 2018 umeabot <umeabot> 3.3.5-2.mga7
+ Revision: 1279543
- Mageia 7 Mass Rebuild

* Mon Jul 30 2018 daviddavid <daviddavid> 3.3.5-1.mga7
+ Revision: 1245958
- new version: 3.3.5
+ tv <tv>
- new release

* Thu Feb 04 2016 umeabot <umeabot> 3.2-6.mga6
+ Revision: 935102
- Mageia 6 Mass Rebuild

* Wed Oct 15 2014 umeabot <umeabot> 3.2-5.mga5
+ Revision: 748026
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 3.2-4.mga5
+ Revision: 682425
- Mageia 5 Mass Rebuild

* Sat Oct 19 2013 umeabot <umeabot> 3.2-3.mga4
+ Revision: 536163
- Mageia 4 Mass Rebuild

* Sun Sep 22 2013 neoclust <neoclust> 3.2-2.mga4
+ Revision: 483540
- imported package mingw-eigen3


* Sat Aug 03 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.2-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Wed Jul 24 2013 Sandro Mani <manisandro@gmail.com> - 3.2-1
- Update to release 3.2

* Fri Apr 19 2013 Sandro Mani <manisandro@gmail.com> - 3.1.3-1
- Update to release 3.1.3

* Tue Mar 05 2013 Sandro Mani <manisandro@gmail.com> - 3.1.2-1
- Initial fedora package
